@@ -1,6 +1,6 @@
 #ifndef G_BASE_DEFINED
 #define G_BASE_DEFINED
-#define GCLIB_VERSION "0.11.3"
+#define GCLIB_VERSION "0.11.4"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -356,6 +356,13 @@ class GSeg {
 	  return (s->start<=start && s->end>=end);
   }
 
+  bool equals(GSeg& d){
+      return (start==d.start && end==d.end);
+  }
+  bool equals(GSeg* d){
+      return (start==d->start && end==d->end);
+  }
+
   //fuzzy coordinate matching:
   bool coordMatch(GSeg* s, uint fuzz=0) { //caller must check for s!=NULL
     if (fuzz==0) return (start==s->start && end==s->end);
