@@ -122,13 +122,16 @@ struct CTransfrag {
 	GVec<int> nodes;
 	GBitVec pattern;
 	float abundance;
-	bool real;
 	float srabund; // keeps abundance associated to srfrag
 	GVec<CPath> path; // stores all the possible paths that leave from a node to reach next node in a transfrag, and distributes the abundance of the transfrag between all possible continuations
 	float usepath;
 	int weak; // number of weak links
-	CTransfrag(GVec<int>& _nodes,GBitVec& bit, float abund=0, bool treal=false, float sr=0):nodes(_nodes),pattern(bit),abundance(abund),real(treal),srabund(sr),path(),usepath(-1),weak(-1) {}
-	CTransfrag(float abund=0, bool treal=false):nodes(),pattern(),abundance(abund),real(treal),srabund(0),path(),usepath(-1),weak(-1) {
+	bool real:1;
+	bool guide:1;
+	uint longstart; // for long reads: min start of all longreads sharing transfrag
+	uint longend; // for long reads: max end of all longreads sharing transfrag
+	CTransfrag(GVec<int>& _nodes,GBitVec& bit, float abund=0, bool treal=false, bool tguide=false,float sr=0):nodes(_nodes),pattern(bit),abundance(abund),srabund(sr),path(),usepath(-1),weak(-1),real(treal),guide(tguide),longstart(false),longend(false) {}
+	CTransfrag(float abund=0, bool treal=false,bool tguide=false):nodes(),pattern(),abundance(abund),srabund(0),path(),usepath(-1),weak(-1),real(treal),guide(tguide),longstart(false),longend(false) {
 	}
 };
 
@@ -217,6 +220,13 @@ struct CPred{
 	CPred(int p=0,float c=0):predno(p),cov(c) {}
 };
 
+struct CLongTrf{
+	int t;
+	float cov;
+	GVec<int> group;
+	CLongTrf(int tno=0,float c=0):t(tno),cov(c),group() {}
+};
+
 struct CPrediction:public GSeg {
 	int geneno;
 	GffObj* t_eq; //equivalent reference transcript (guide)
@@ -492,6 +502,8 @@ struct CGraphnode:public GSeg {
 struct CJunction:public GSeg {
 	char strand; //-1,0,1
 	char guide_match; //exact match of a ref intron?
+	char consleft; // -1,0,1 -1 is not set up, 0 is non consensus, 1 is consensus
+	char consright; // -1,0,1 -1 is not set up, 0 is non consensus, 1 is consensus
 	double nreads;
 	double nreads_good;
 	double leftsupport;
@@ -499,7 +511,7 @@ struct CJunction:public GSeg {
 	double nm; // number of reads with a high nm (high mismatch)
 	double mm; // number of reads that support a junction with both anchors bigger than longintronanchor
 	CJunction(int s=0,int e=0, char _strand=0):GSeg(s,e),
-			strand(_strand), guide_match(0), nreads(0),nreads_good(0),
+			strand(_strand), guide_match(0), consleft(-1), consright(-1),nreads(0),nreads_good(0),
 			leftsupport(0),rightsupport(0),nm(0),mm(0) {}
 	bool operator<(CJunction& b) {
 		if (start<b.start) return true;
