@@ -11,7 +11,7 @@
 #include "proc_mem.h"
 #endif
 
-#define VERSION "2.0.6"
+#define VERSION "2.1.1"
 
 //#define DEBUGPRINT 1
 
@@ -45,6 +45,7 @@ Assemble RNA-Seq alignments into potential transcripts.\n\
  -l name prefix for output transcripts (default: STRG)\n\
  -f minimum isoform fraction (default: 0.01)\n\
  -L use long reads settings (default:false)\n\
+ -R if long reads are provided, just clean and collapse the reads but do not assemble\n\
  -m minimum assembled transcript length (default: 200)\n\
  -a minimum anchor length for junctions (default: 10)\n\
  -j minimum junction coverage (default: 1)\n\
@@ -130,6 +131,7 @@ bool guided=false;
 bool trim=true;
 bool eonly=false; // parameter -e ; for mergeMode includes estimated coverage sum in the merged transcripts
 bool longreads=false;
+bool rawreads=false;
 bool nomulti=false;
 bool enableNames=false;
 bool includecov=false;
@@ -264,7 +266,7 @@ int main(int argc, char* argv[]) {
 
  // == Process arguments.
  GArgs args(argc, argv,
-   "debug;help;version;conservative;keeptmp;rseq=;bam;fr;rf;merge;exclude=zEihvteuLx:n:j:s:D:G:C:S:l:m:o:a:j:c:f:p:g:P:M:Bb:A:F:T:");
+   "debug;help;version;conservative;keeptmp;rseq=;bam;fr;rf;merge;exclude=zEihvteuLRx:n:j:s:D:G:C:S:l:m:o:a:j:c:f:p:g:P:M:Bb:A:F:T:");
  args.printError(USAGE, true);
 
  processOptions(args);
@@ -891,6 +893,7 @@ void processOptions(GArgs& args) {
 	   exit(0);
 	}
 
+
 	 longreads=(args.getOpt('L')!=NULL);
 	 if(longreads) {
 		 bundledist=0;
@@ -998,6 +1001,17 @@ void processOptions(GArgs& args) {
 	 s=args.getOpt('j');
 	 if (!s.is_empty()) junctionthr=s.asInt();
 
+
+	 rawreads=(args.getOpt('R')!=NULL);
+	 if(rawreads) {
+		 if(!longreads) {
+			 if(verbose) GMessage("Enable longreads processing\n");
+			 longreads=true;
+			 bundledist=0;
+		 }
+		 readthr=0;
+	 }
+
 	 s=args.getOpt('c');
 	 if (!s.is_empty()) {
 		 readthr=(float)s.asDouble();
@@ -1008,7 +1022,6 @@ void processOptions(GArgs& args) {
 	 else if(mergeMode) readthr=0;
 
 
-
 	 s=args.getOpt('g');
 	 if (!s.is_empty()) {
 		 bundledist=s.asInt();
@@ -1076,7 +1089,10 @@ void processOptions(GArgs& args) {
 	 //isunitig=(args.getOpt('U')!=NULL);
 
 	 eonly=(args.getOpt('e')!=NULL);
-	 if(eonly && mergeMode) {
+	 if(eonly && rawreads) {
+		 if(verbose) GMessage("Error: can not use -e and -R at the same time; parameter -e will be ignored\n");
+	 }
+	 else if(eonly && mergeMode) {
 		 eonly=false;
 		 includecov=true;
 	 }
